@@ -1,14 +1,10 @@
 import os
 from collections import namedtuple
-from functools import partial
 import pandas as pd
-import numpy as np
 
 from everviz.log import get_logger
 
-DataSources = namedtuple(
-    "DataSource", ["objective_values", "objective_statistics", "total_objective_values"]
-)
+DataSources = namedtuple("DataSource", ["objective_values", "total_objective_values"])
 
 logger = get_logger()
 
@@ -27,9 +23,9 @@ def _total_objective_values_from_api(api):
 
 def _objective_values(data):
     # Sort by the index columns.
-    data = data.drop(columns=["realization"])
+    data = data.drop(columns=["simulation"])
     sorted_values = (
-        data.set_index(["function", "batch", "simulation"]).sort_index().reset_index()
+        data.set_index(["function", "batch", "realization"]).sort_index().reset_index()
     )
     return sorted_values
 
@@ -40,24 +36,6 @@ def _total_objective_values(data):
     return sorted_values
 
 
-def _objective_statistics(data):
-    # Aggregate the values over the simulations, using pivot_table, keeping the
-    # batch and function as the multi-index, calculating statistics of the
-    # values over the simulations.
-    statistics = pd.pivot_table(
-        data,
-        values="value",
-        index=["function", "batch"],
-        aggfunc=[np.mean, partial(np.quantile, q=0.1), partial(np.quantile, q=0.9),],
-    )
-    statistics.columns = ["Mean", "P10", "P90"]
-
-    # Sort the multi index, and reset them to columns.
-    sorted_statistics = statistics.sort_index().reset_index()
-
-    return sorted_statistics
-
-
 def _set_up_data_sources(api):
     everest_folder = api.output_folder
     everviz_path = os.path.join(everest_folder, "everviz")
@@ -70,11 +48,6 @@ def _set_up_data_sources(api):
     values.to_csv(objective_values_file, index=False)
     logger.info(f"File created: {objective_values_file}")  # pylint: disable=W1203
 
-    objective_statistics_file = os.path.join(everviz_path, "objective_statistics.csv")
-    statistics = _objective_statistics(data)
-    statistics.to_csv(objective_statistics_file, index=False)
-    logger.info(f"File created: {objective_statistics_file}")  # pylint: disable=W1203
-
     logger.info("Generating total objective values plot")
     data = _total_objective_values_from_api(api)
 
@@ -87,7 +60,6 @@ def _set_up_data_sources(api):
 
     return DataSources(
         objective_values=objective_values_file,
-        objective_statistics=objective_statistics_file,
         total_objective_values=total_objective_values_file,
     )
 
@@ -105,12 +77,7 @@ def page_layout(api):
         "title": "Objectives",
         "content": [
             "## Objective function values",
-            {
-                "ObjectivesPlot": {
-                    "values_file": sources.objective_values,
-                    "statistics_file": sources.objective_statistics,
-                },
-            },
+            {"ObjectivesPlot": {"csv_file": sources.objective_values,},},
             f"## {_single_objective_title(api)}",
             {"SingleObjectivesPlot": {"csv_file": sources.total_objective_values,},},
         ],
