@@ -63,7 +63,15 @@ class ControlsPlot(WebvizPluginABC):
                             },
                         ),
                         html.Div(
-                            [dcc.Graph(id=self.graph_id)],
+                            [
+                                dcc.Graph(
+                                    id=self.graph_id,
+                                    config={
+                                        "modeBarButtonsToRemove": ["toImage"],
+                                        "displaylogo": False,
+                                    },
+                                )
+                            ],
                             style={"width": "69%", "display": "inline-block"},
                         ),
                     ]
