@@ -13,6 +13,9 @@ from dash.dependencies import Output, Input, State
 from webviz_config import WebvizPluginABC
 from webviz_config.webviz_assets import WEBVIZ_ASSETS
 from everviz.data.load_csv.get_data import get_data
+from everviz.util import parse_range
+
+from .util import calculate_statistics
 
 
 class ObjectivesPlot(WebvizPluginABC):
@@ -27,15 +30,17 @@ class ObjectivesPlot(WebvizPluginABC):
     a P10-P90 range.
     """
 
-    def __init__(self, app, values_file, statistics_file):
+    def __init__(self, app, csv_file):
         super().__init__()
 
         self.graph_id = f"graph-{uuid4()}"
         self.radio_id = f"dropdown-{uuid4()}"
+        self.radio_id_mode = f"dropdown-{uuid4()}"
         self.function_dropdown_id = f"dropdown-{uuid4()}"
+        self.realization_filter_check_id = f"check-{uuid4()}"
+        self.realization_filter_input_id = f"input-{uuid4()}"
 
-        self.values_file = values_file
-        self.statistics_file = statistics_file
+        self.csv_file = csv_file
         self.set_callbacks(app)
 
         ASSETS_DIR = Path(pkg_resources.resource_filename("everviz", "assets"))
@@ -43,13 +48,12 @@ class ObjectivesPlot(WebvizPluginABC):
 
     def add_webvizstore(self):
         return [
-            (get_data, [{"values_file": self.values_file}]),
-            (get_data, [{"statistics_file": self.statistics_file}]),
+            (get_data, [{"csv_file": self.csv_file}]),
         ]
 
     @property
     def layout(self):
-        data = get_data(self.statistics_file)
+        data = get_data(self.csv_file)
 
         functions = data["function"].unique()
         function_dropdown_options = [{"label": i, "value": i} for i in functions]
@@ -63,7 +67,7 @@ class ObjectivesPlot(WebvizPluginABC):
             ),
         ]
 
-        radio_options = ["Statistics", "Data"]
+        radio_options = ["Statistics", "Values", "Normalized", "Weighted + Normalized"]
         radio_elements = [
             dcc.RadioItems(
                 id=self.radio_id,
@@ -71,6 +75,36 @@ class ObjectivesPlot(WebvizPluginABC):
                 value=radio_options[1],
                 labelStyle={"display": "inline-block"},
                 style={"margin-top": 20},
+            ),
+            html.Label("Style:"),
+            dcc.RadioItems(
+                id=self.radio_id_mode,
+                options=[
+                    {"label": "line", "value": "lines"},
+                    {"label": "scatter", "value": "markers"},
+                ],
+                value="lines",
+                labelStyle={"display": "inline-block"},
+            ),
+        ]
+
+        realization_elements = [
+            html.Div(
+                [
+                    dcc.Checklist(
+                        id=self.realization_filter_check_id,
+                        options=[{"label": "Filter realizations:", "value": "filter"}],
+                        style={"display": "inline-block", "margin-right": 8},
+                    ),
+                    dcc.Input(
+                        id=self.realization_filter_input_id,
+                        type="text",
+                        placeholder="example: 0, 3, 6-10",
+                        pattern=r"\s*|([0-9]+(\s*-\s*[0-9]+)?)(\s*,\s*[0-9]+(\s*-\s*[0-9]+)?)*",
+                        style={"display": "inline-block"},
+                    ),
+                ],
+                style={"margin-top": 20},
             )
         ]
 
@@ -79,7 +113,7 @@ class ObjectivesPlot(WebvizPluginABC):
                 html.Div(
                     [
                         html.Div(
-                            func_elements + radio_elements,
+                            func_elements + radio_elements + realization_elements,
                             style={
                                 "width": "29%",
                                 "display": "inline-block",
@@ -87,7 +121,15 @@ class ObjectivesPlot(WebvizPluginABC):
                             },
                         ),
                         html.Div(
-                            [dcc.Graph(id=self.graph_id)],
+                            [
+                                dcc.Graph(
+                                    id=self.graph_id,
+                                    config={
+                                        "modeBarButtonsToRemove": ["toImage"],
+                                        "displaylogo": False,
+                                    },
+                                )
+                            ],
                             style={"width": "69%", "display": "inline-block"},
                         ),
                     ]
@@ -99,39 +141,68 @@ class ObjectivesPlot(WebvizPluginABC):
         @app.callback(
             self.plugin_data_output,
             [self.plugin_data_requested],
-            [State(self.radio_id, "value")],
+            [
+                State(self.radio_id, "value"),
+                State(self.realization_filter_check_id, "value"),
+                State(self.realization_filter_input_id, "value"),
+            ],
         )
-        def user_download_data(data_requested, radio_value):
+        def user_download_data(
+            data_requested, radio_value, realizations_check, realizations_input,
+        ):
             if data_requested:
-                file_path = (
-                    self.statistics_file
-                    if radio_value == "Statistics"
-                    else self.values_file
-                )
+                content = get_data(self.csv_file)
+                if realizations_check:
+                    realizations = parse_range(realizations_input)
+                    if realizations:
+                        content = content[content["realization"].isin(realizations)]
+                if radio_value == "Statistics":
+                    filename = "objective_statistics.csv"
+                    content = calculate_statistics(content)
+                else:
+                    filename = "objective_values.csv"
                 return WebvizPluginABC.plugin_data_compress(
-                    [
-                        {
-                            "filename": Path(file_path).name,
-                            "content": get_data(file_path).to_csv(),
-                        }
-                    ]
+                    [{"filename": filename, "content": content.to_csv(),}]
                 )
             return ""
 
         @app.callback(
-            Output(self.graph_id, "figure"),
-            [Input(self.function_dropdown_id, "value"), Input(self.radio_id, "value"),],
+            Output(self.realization_filter_input_id, "disabled"),
+            [Input(self.realization_filter_check_id, "value")],
         )
-        def update_graph(func_list, radio_value):
-            # # The key_list arguments is the list of functions to plot.
+        def set_button_enabled_state(filter_realizations):
+            return not filter_realizations
+
+        @app.callback(
+            Output(self.graph_id, "figure"),
+            [
+                Input(self.function_dropdown_id, "value"),
+                Input(self.radio_id, "value"),
+                Input(self.radio_id_mode, "value"),
+                Input(self.realization_filter_check_id, "value"),
+                Input(self.realization_filter_input_id, "value"),
+            ],
+        )
+        def update_graph(
+            func_list, radio_value, plot_mode, realizations_check, realizations_input
+        ):
+            # The key_list arguments is the list of functions to plot.
             if func_list is None:
                 return {}
 
-            # # Get the data, setting its index.
+            # Get the data, filter if requested.
+            data = get_data(self.csv_file)
+            if realizations_check:
+                realizations = parse_range(realizations_input)
+                if realizations:
+                    data = data[data["realization"].isin(realizations)]
+            if len(data) == 0:
+                return {}
+
             if radio_value == "Statistics":
-                data = get_data(self.statistics_file).set_index("function")
-            else:
-                data = get_data(self.values_file).set_index("function")
+                data = calculate_statistics(data)
+
+            data = data.set_index("function")
 
             # Make a cycle iterator over the plotly colors.
             colors = cycle(DEFAULT_PLOTLY_COLORS)
@@ -148,7 +219,7 @@ class ObjectivesPlot(WebvizPluginABC):
                             go.Scatter(
                                 y=func_data["P90"],
                                 x=func_data["batch"],
-                                mode="lines",
+                                mode=plot_mode,
                                 marker={"size": 10},
                                 line={"color": color},
                                 name=key + "(P90)",
@@ -157,7 +228,7 @@ class ObjectivesPlot(WebvizPluginABC):
                             go.Scatter(
                                 y=func_data["P10"],
                                 x=func_data["batch"],
-                                mode="lines",
+                                mode=plot_mode,
                                 line={"color": color},
                                 marker={"size": 10},
                                 fill="tonexty",
@@ -167,7 +238,7 @@ class ObjectivesPlot(WebvizPluginABC):
                             go.Scatter(
                                 y=func_data["Mean"],
                                 x=func_data["batch"],
-                                mode="lines",
+                                mode=plot_mode,
                                 marker={"size": 10},
                                 line={"color": color},
                                 name=key,
@@ -176,11 +247,17 @@ class ObjectivesPlot(WebvizPluginABC):
                         ]
                     )
                 else:
+                    y_values = func_data["value"]
+                    if radio_value == "Normalized":
+                        y_values = y_values * func_data["norm"]
+                    elif radio_value == "Weighted + Normalized":
+                        y_values = y_values * func_data["norm"] * func_data["weight"]
+
                     traces.append(
                         go.Scatter(
-                            y=func_data["value"],
+                            y=y_values,
                             x=func_data["batch"],
-                            mode="markers",
+                            mode=plot_mode,
                             marker={"size": 10},
                             name=key,
                             showlegend=True,
